==> tikka-0.16.7.tar.gz: tikka-0.16.7/tikka/slots/pyqt/entities/constants.py <==
# Copyright 2021 Vincent Texier <vit@free.fr>
#
# This software is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This software is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# Fonts
ADDRESS_MONOSPACE_FONT_NAME = "Courier"

# Style
NUMERIC_DISPLAY_COLOR_BLUE = "#229CFC"
NUMERIC_DISPLAY_COLOR_GREEN = "#22e36c"
NUMERIC_DISPLAY_COLOR_RED = "#fe7980"

# icon paths
ICON_ACCOUNT_NO_WALLET = ":/images/locked_no_wallet"
ICON_ACCOUNT_WALLET_LOCKED = ":/images/locked"
ICON_ACCOUNT_WALLET_UNLOCKED = ":/images/unlocked"
ICON_NETWORK_CONNECTED = ":/icons/connected"
ICON_NETWORK_DISCONNECTED = ":/icons/disconnected"
ICON_IDENTITY = ":/icons/member_icon"
ICON_IDENTITY_MEMBER = ":/icons/member"
ICON_IDENTITY_NOT_MEMBER = ":/icons/not_member"
ICON_IDENTITY_MEMBER_NOT_VALIDATED = ":/icons/member_warning"
ICON_SMITH = ":/icons/smith"
ICON_LOADER = ":/icons/loader"

# no activity delay before executing function when typing in ms
DEBOUNCE_TIME = 300

# preferences keys
SELECTED_TAB_PAGE_PREFERENCES_KEY = "selected_tab_page"
WALLET_LOAD_DEFAULT_DIRECTORY_PREFERENCES_KEY = "wallet_load_default_directory"
WALLET_SAVE_DEFAULT_DIRECTORY_PREFERENCES_KEY = "wallet_save_default_directory"
SELECTED_UNIT_PREFERENCES_KEY = "selected_unit"
ACCOUNTS_TABLE_SORT_COLUMN_PREFERENCES_KEY = "accounts_table_sort_column"
ACCOUNTS_TABLE_SORT_ORDER_PREFERENCES_KEY = "accounts_table_sort_order"
ACCOUNTS_TABLE_CATEGORY_FILTER_PREFERENCES_KEY = "accounts_table_category_filter"
ACCOUNTS_TABLE_WALLET_FILTER_PREFERENCES_KEY = "accounts_table_wallet_filter"
TRANSFER_SENDER_ADDRESS_PREFERENCES_KEY = "transfer_sender_address"
TRANSFER_RECIPIENT_ADDRESS_PREFERENCES_KEY = "transfer_recipient_address"
SMITH_SELECTED_ACCOUNT_ADDRESS = "smith_selected_account_address"
SMITH_INVITE_SELECTED_ACCOUNT_ADDRESS = "smith_invite_selected_account_address"
SMITH_CERTIFY_SELECTED_IDENTITY_INDEX = "smith_certify_selected_identity_index"
TECHNICAL_COMMITTEE_SELECTED_ACCOUNT_ADDRESS = (
    "technical_committee_selected_account_address"
)
NODES_TABLE_SORT_COLUMN_PREFERENCES_KEY = "nodes_table_sort_column"
NODES_TABLE_SORT_ORDER_PREFERENCES_KEY = "nodes_table_sort_order"
INDEXERS_TABLE_SORT_COLUMN_PREFERENCES_KEY = "indexers_table_sort_column"
INDEXERS_TABLE_SORT_ORDER_PREFERENCES_KEY = "indexers_table_sort_order"
TABS_PREFERENCES_KEY = "tabs_opened"
SAVE_DATA_DEFAULT_DIR_PREFERENCES_KEY = "save_data_default_dir"
TRANSFERS_EXPORT_DEFAULT_DIRECTORY_PREFERENCES_KEY = (
    "transfers_export_default_directory"
)

==> tikka-0.19.0.tar.gz: tikka-0.19.0/tikka/slots/pyqt/entities/constants.py <==
# Copyright 2021 Vincent Texier <vit@free.fr>
#
# This software is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This software is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# Fonts
ADDRESS_MONOSPACE_FONT_NAME = "Courier"

# Style
NUMERIC_DISPLAY_COLOR_BLUE = "#229CFC"
NUMERIC_DISPLAY_COLOR_GREEN = "#22e36c"
NUMERIC_DISPLAY_COLOR_RED = "#fe7980"

# icon paths
ICON_ACCOUNT_NO_WALLET = ":/images/locked_no_wallet"
ICON_ACCOUNT_WALLET_LOCKED = ":/images/locked"
ICON_ACCOUNT_WALLET_UNLOCKED = ":/images/unlocked"
ICON_NETWORK_CONNECTED = ":/icons/connected"
ICON_NETWORK_DISCONNECTED = ":/icons/disconnected"
ICON_IDENTITY = ":/icons/member_icon"
ICON_IDENTITY_MEMBER = ":/icons/member"
ICON_IDENTITY_NOT_MEMBER = ":/icons/not_member"
ICON_IDENTITY_MEMBER_NOT_VALIDATED = ":/icons/member_warning"
ICON_SMITH = ":/icons/smith"
ICON_LOADER = ":/icons/loader"

# no activity delay before executing function when typing in ms
DEBOUNCE_TIME = 300

# preferences keys
SELECTED_TAB_PAGE_PREFERENCES_KEY = "selected_tab_page"
WALLET_LOAD_DEFAULT_DIRECTORY_PREFERENCES_KEY = "wallet_load_default_directory"
WALLET_SAVE_DEFAULT_DIRECTORY_PREFERENCES_KEY = "wallet_save_default_directory"
SELECTED_UNIT_PREFERENCES_KEY = "selected_unit"
ACCOUNTS_TABLE_SORT_COLUMN_PREFERENCES_KEY = "accounts_table_sort_column"
ACCOUNTS_TABLE_SORT_ORDER_PREFERENCES_KEY = "accounts_table_sort_order"
ACCOUNTS_TABLE_CATEGORY_FILTER_PREFERENCES_KEY = "accounts_table_category_filter"
ACCOUNTS_TABLE_WALLET_FILTER_PREFERENCES_KEY = "accounts_table_wallet_filter"
TRANSFER_SENDER_ADDRESS_PREFERENCES_KEY = "transfer_sender_address"
TRANSFER_RECIPIENT_ADDRESS_PREFERENCES_KEY = "transfer_recipient_address"
SMITH_SELECTED_ACCOUNT_ADDRESS = "smith_selected_account_address"
SMITH_INVITE_SELECTED_ACCOUNT_ADDRESS = "smith_invite_selected_account_address"
SMITH_CERTIFY_SELECTED_IDENTITY_INDEX = "smith_certify_selected_identity_index"
TECHNICAL_COMMITTEE_SELECTED_ACCOUNT_ADDRESS = (
    "technical_committee_selected_account_address"
)
NODES_TABLE_SORT_COLUMN_PREFERENCES_KEY = "nodes_table_sort_column"
NODES_TABLE_SORT_ORDER_PREFERENCES_KEY = "nodes_table_sort_order"
INDEXERS_TABLE_SORT_COLUMN_PREFERENCES_KEY = "indexers_table_sort_column"
INDEXERS_TABLE_SORT_ORDER_PREFERENCES_KEY = "indexers_table_sort_order"
DATAPODS_TABLE_SORT_COLUMN_PREFERENCES_KEY = "datapods_table_sort_column"
DATAPODS_TABLE_SORT_ORDER_PREFERENCES_KEY = "datapods_table_sort_order"
TABS_PREFERENCES_KEY = "tabs_opened"
SAVE_DATA_DEFAULT_DIR_PREFERENCES_KEY = "save_data_default_dir"
TRANSFERS_EXPORT_DEFAULT_DIRECTORY_PREFERENCES_KEY = (
    "transfers_export_default_directory"
)
